import { getExistingEquivalentLabels } from "./getExistingEquivalentLabels.js";
import { outcomeLabels } from "./outcomeLabels.js";
async function initializeRepositoryLabels(octokit, options) {
  const { data: existingLabels } = await octokit.request(
    "GET /repos/{owner}/{repo}/labels",
    {
      headers: {
        "X-GitHub-Api-Version": "2022-11-28"
      },
      owner: options.owner,
      repo: options.repository
    }
  );
  for (const outcome of outcomeLabels) {
    const existingEquivalents = getExistingEquivalentLabels(
      existingLabels,
      outcome.name
    );
    if (!existingEquivalents.length) {
      await octokit.request("POST /repos/{owner}/{repo}/labels", {
        color: outcome.color.replace("#", ""),
        description: outcome.description,
        headers: {
          "X-GitHub-Api-Version": "2022-11-28"
        },
        name: outcome.name,
        owner: options.owner,
        repo: options.repository
      });
      continue;
    }
    for (const existingEquivalent of existingEquivalents) {
      if (existingEquivalent.name !== outcome.name && existingLabels.some((existing) => existing.name === outcome.name)) {
        await octokit.request("DELETE /repos/{owner}/{repo}/labels/{name}", {
          headers: {
            "X-GitHub-Api-Version": "2022-11-28"
          },
          name: existingEquivalent.name,
          owner: options.owner,
          repo: options.repository
        });
        continue;
      }
      if (outcome.color !== existingEquivalent.color || outcome.description !== existingEquivalent.description || outcome.name !== existingEquivalent.name) {
        await octokit.request("PATCH /repos/{owner}/{repo}/labels/{name}", {
          color: outcome.color.replace("#", ""),
          description: outcome.description,
          headers: {
            "X-GitHub-Api-Version": "2022-11-28"
          },
          name: existingEquivalent.name,
          new_name: outcome.name,
          owner: options.owner,
          repo: options.repository
        });
      }
    }
  }
}
export {
  initializeRepositoryLabels
};
//# sourceMappingURL=initializeRepositoryLabels.js.map